@@ -512,7 +512,7 @@ impl Socket
 			//
 			// If people disagree, feel free to open a Gitlab issue.
 			if let Some(callback) = &*inner.pipe_notify.read().unwrap() {
-				(*callback)(pipe, ev)
+				(*callback)(pipe, ev);
 			}
 		});
 	}
@@ -559,7 +559,7 @@ impl Hash for Socket
 	fn hash<H: Hasher>(&self, state: &mut H)
 	{
 		let id = unsafe { nng_sys::nng_socket_id(self.inner.handle) };
-		id.hash(state)
+		id.hash(state);
 	}
 }
 
@@ -663,17 +663,18 @@ impl Drop for Inner
 
 /// A socket that is open in "raw" mode.
 ///
-/// Most NNG applications will interact with sockets in "cooked" mode. This mode will automatically
-/// handle the full semantics of the protocol, such as _req_ sockets automatically matching a reply
-/// to a request or resenting a request periodically if no reply was received.
+/// Most NNG applications will interact with sockets in "cooked" mode. This mode
+/// will automatically handle the full semantics of the protocol, such as _req_
+/// sockets automatically matching a reply to a request or resenting a request
+/// periodically if no reply was received.
 ///
-/// However, there are situations, such as with [proxies][1], where it is desirable to bypass these
-/// semantics and pass messages without any extra handling. This is possible with "raw" mode
-/// sockets.
+/// However, there are situations, such as with [proxies][1], where it is
+/// desirable to bypass these semantics and pass messages without any extra
+/// handling. This is possible with "raw" mode sockets.
 ///
-/// When using these sockets, the user is responsible for applying any additional socket semantics
-/// which typically means inspecting the message [`Header`] on incoming messages and supplying them
-/// on outgoing messages.
+/// When using these sockets, the user is responsible for applying any
+/// additional socket semantics which typically means inspecting the message
+/// [`Header`] on incoming messages and supplying them on outgoing messages.
 ///
 /// [1]: fn.forwarder.html
 /// [`Header`]: struct.Header.html
